Latent parameter tau-squared to form the Laplace prior on the coefficients of the Lasso from a normal-mixture.
lambda
Initial value for lambda.
shape1
First shape parameter for the Beta distribution.
shape2
Second shape parameter for the Beta distribution.
max
Maximum value of lambda.
ncp
Dummy parameter.
Value
Returns a value for lambda to use in the Gibbs samplers of the functions in the SafeBayes package.
Details
Metropolis-Hastings algorithm to sample lambda with a Beta prior from (de los Campos et al., 2009) for the Bayesian Lasso regression model.
References
de los Campos G., H. Naya, D. Gianola, J. Crossa, A. Legarra, E. Manfredi, K. Weigel and J. Cotes. 2009.
Predicting Quantitative Traits with Regression Models for Dense Molecular Markers and Pedigree. Genetics182: 375-385.